@@ -1,5 +1,5 @@
 package XML::Grammar::Fiction::App::FromProto;
-
+$XML::Grammar::Fiction::App::FromProto::VERSION = 'v0.15.0';
 use strict;
 use warnings;
 use autodie;
@@ -17,9 +17,6 @@ use XML::Grammar::Fiction::FromProto::Parser::QnD;
 
 
 
-our $VERSION = 'v0.14.12';
-
-
 sub run
 {
     my $output_filename;
@@ -65,7 +62,7 @@ to convert from a well-formed plaintext format to Fiction-XML.
 
 =head1 VERSION
 
-version v0.14.12
+version v0.15.0
 
 =head1 SYNOPSIS
 
@@ -74,7 +71,7 @@ version v0.14.12
 
 =head1 VERSION
 
-Version 0.14.12
+version v0.15.0
 
 =head1 FUNCTIONS
 
@@ -113,7 +110,7 @@ feature.
 
 You can find documentation for this module with the perldoc command.
 
-  perldoc XML::Grammar::Fiction
+  perldoc XML::Grammar::Fiction::App::FromProto
 
 =head2 Websites
 
@@ -128,7 +125,7 @@ MetaCPAN
 
 A modern, open-source CPAN search engine, useful to view POD in HTML format.
 
-L<http://metacpan.org/release/XML-Grammar-Fiction>
+L<https://metacpan.org/release/XML-Grammar-Fiction>
 
 =item *
 
@@ -164,14 +161,6 @@ L<http://cpanratings.perl.org/d/XML-Grammar-Fiction>
 
 =item *
 
-CPAN Forum
-
-The CPAN Forum is a web forum for discussing Perl modules.
-
-L<http://cpanforum.com/dist/XML-Grammar-Fiction>
-
-=item *
-
 CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
@@ -182,7 +171,7 @@ L<http://cpants.cpanauthors.org/dist/XML-Grammar-Fiction>
 
 CPAN Testers
 
-The CPAN Testers is a network of smokers who run automated tests on uploaded CPAN distributions.
+The CPAN Testers is a network of smoke testers who run automated tests on uploaded CPAN distributions.
 
 L<http://www.cpantesters.org/distro/X/XML-Grammar-Fiction>
 
