@@ -1,5 +1,5 @@
 package XML::Grammar::Fiction::App::ToHTML;
-
+$XML::Grammar::Fiction::App::ToHTML::VERSION = 'v0.15.0';
 use strict;
 use warnings;
 use autodie;
@@ -13,9 +13,6 @@ use Getopt::Long;
 use XML::Grammar::Fiction::ToHTML;
 
 
-our $VERSION = 'v0.14.12';
-
-
 sub run
 {
     my $output_filename;
@@ -60,7 +57,7 @@ Fiction-XML file to HTML
 
 =head1 VERSION
 
-version v0.14.12
+version v0.15.0
 
 =head1 SYNOPSIS
 
@@ -69,7 +66,7 @@ version v0.14.12
 
 =head1 VERSION
 
-Version 0.14.12
+version v0.15.0
 
 =head1 FUNCTIONS
 
@@ -108,7 +105,7 @@ feature.
 
 You can find documentation for this module with the perldoc command.
 
-  perldoc XML::Grammar::Fiction
+  perldoc XML::Grammar::Fiction::App::ToHTML
 
 =head2 Websites
 
@@ -123,7 +120,7 @@ MetaCPAN
 
 A modern, open-source CPAN search engine, useful to view POD in HTML format.
 
-L<http://metacpan.org/release/XML-Grammar-Fiction>
+L<https://metacpan.org/release/XML-Grammar-Fiction>
 
 =item *
 
@@ -159,14 +156,6 @@ L<http://cpanratings.perl.org/d/XML-Grammar-Fiction>
 
 =item *
 
-CPAN Forum
-
-The CPAN Forum is a web forum for discussing Perl modules.
-
-L<http://cpanforum.com/dist/XML-Grammar-Fiction>
-
-=item *
-
 CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
@@ -177,7 +166,7 @@ L<http://cpants.cpanauthors.org/dist/XML-Grammar-Fiction>
 
 CPAN Testers
 
-The CPAN Testers is a network of smokers who run automated tests on uploaded CPAN distributions.
+The CPAN Testers is a network of smoke testers who run automated tests on uploaded CPAN distributions.
 
 L<http://www.cpantesters.org/distro/X/XML-Grammar-Fiction>
 
