@@ -1,12 +1,10 @@
 package XML::Grammar::Fiction::Err;
-
+$XML::Grammar::Fiction::Err::VERSION = 'v0.15.0';
 use strict;
 use warnings;
 
 
 
-our $VERSION = 'v0.14.12';
-
 use Exception::Class
     (
         "XML::Grammar::Fiction::Err::Base",
@@ -70,7 +68,7 @@ XML::Grammar::Fiction
 
 =head1 VERSION
 
-version v0.14.12
+version v0.15.0
 
 =head1 SYNOPSIS
 
@@ -91,7 +89,7 @@ These are exceptions for L<XML::Grammar::Fiction> based on L<Exception::Class>
 
 =head1 VERSION
 
-Version 0.14.12
+version v0.15.0
 
 =head1 AUTHOR
 
@@ -124,7 +122,7 @@ feature.
 
 You can find documentation for this module with the perldoc command.
 
-  perldoc XML::Grammar::Fiction
+  perldoc XML::Grammar::Fiction::Err
 
 =head2 Websites
 
@@ -139,7 +137,7 @@ MetaCPAN
 
 A modern, open-source CPAN search engine, useful to view POD in HTML format.
 
-L<http://metacpan.org/release/XML-Grammar-Fiction>
+L<https://metacpan.org/release/XML-Grammar-Fiction>
 
 =item *
 
@@ -175,14 +173,6 @@ L<http://cpanratings.perl.org/d/XML-Grammar-Fiction>
 
 =item *
 
-CPAN Forum
-
-The CPAN Forum is a web forum for discussing Perl modules.
-
-L<http://cpanforum.com/dist/XML-Grammar-Fiction>
-
-=item *
-
 CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
@@ -193,7 +183,7 @@ L<http://cpants.cpanauthors.org/dist/XML-Grammar-Fiction>
 
 CPAN Testers
 
-The CPAN Testers is a network of smokers who run automated tests on uploaded CPAN distributions.
+The CPAN Testers is a network of smoke testers who run automated tests on uploaded CPAN distributions.
 
 L<http://www.cpantesters.org/distro/X/XML-Grammar-Fiction>
 
