@@ -1,5 +1,5 @@
 package XML::Grammar::Fiction::FromProto;
-
+$XML::Grammar::Fiction::FromProto::VERSION = 'v0.15.0';
 use strict;
 use warnings;
 use autodie;
@@ -13,9 +13,6 @@ extends("XML::Grammar::FictionBase::TagsTree2XML");
 my $fiction_ns = q{http://web-cpan.berlios.de/modules/XML-Grammar-Fortune/fiction-xml-0.2/};
 
 
-our $VERSION = 'v0.14.12';
-
-
 
 my %lookup = (map { $_ => $_ } qw( li ol ul ));
 
@@ -318,11 +315,13 @@ text representing prose to an XML format.
 
 =head1 VERSION
 
-version v0.14.12
+version v0.15.0
 
 =head1 VERSION
 
-Version 0.14.12
+version v0.15.0
+
+=head1 METHODS
 
 =head2 new()
 
@@ -369,7 +368,7 @@ feature.
 
 You can find documentation for this module with the perldoc command.
 
-  perldoc XML::Grammar::Fiction
+  perldoc XML::Grammar::Fiction::FromProto
 
 =head2 Websites
 
@@ -384,7 +383,7 @@ MetaCPAN
 
 A modern, open-source CPAN search engine, useful to view POD in HTML format.
 
-L<http://metacpan.org/release/XML-Grammar-Fiction>
+L<https://metacpan.org/release/XML-Grammar-Fiction>
 
 =item *
 
@@ -420,14 +419,6 @@ L<http://cpanratings.perl.org/d/XML-Grammar-Fiction>
 
 =item *
 
-CPAN Forum
-
-The CPAN Forum is a web forum for discussing Perl modules.
-
-L<http://cpanforum.com/dist/XML-Grammar-Fiction>
-
-=item *
-
 CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
@@ -438,7 +429,7 @@ L<http://cpants.cpanauthors.org/dist/XML-Grammar-Fiction>
 
 CPAN Testers
 
-The CPAN Testers is a network of smokers who run automated tests on uploaded CPAN distributions.
+The CPAN Testers is a network of smoke testers who run automated tests on uploaded CPAN distributions.
 
 L<http://www.cpantesters.org/distro/X/XML-Grammar-Fiction>
 
