@@ -1,13 +1,11 @@
 package XML::Grammar::Fiction::FromProto::Node;
-
+$XML::Grammar::Fiction::FromProto::Node::VERSION = 'v0.15.0';
 use strict;
 use warnings;
 
 use List::Util ();
 
 
-our $VERSION = 'v0.14.12';
-
 use MooX 'late';
 
 sub _short_isa
@@ -36,7 +34,7 @@ use in XML::Grammar::Fiction::FromProto.
 
 =head1 VERSION
 
-version v0.14.12
+version v0.15.0
 
 =head1 DESCRIPTION
 
@@ -44,7 +42,7 @@ Contains several nodes.
 
 =head1 VERSION
 
-Version 0.14.12
+version v0.15.0
 
 =head1 AUTHOR
 
@@ -77,7 +75,7 @@ feature.
 
 You can find documentation for this module with the perldoc command.
 
-  perldoc XML::Grammar::Fiction
+  perldoc XML::Grammar::Fiction::FromProto::Node
 
 =head2 Websites
 
@@ -92,7 +90,7 @@ MetaCPAN
 
 A modern, open-source CPAN search engine, useful to view POD in HTML format.
 
-L<http://metacpan.org/release/XML-Grammar-Fiction>
+L<https://metacpan.org/release/XML-Grammar-Fiction>
 
 =item *
 
@@ -128,14 +126,6 @@ L<http://cpanratings.perl.org/d/XML-Grammar-Fiction>
 
 =item *
 
-CPAN Forum
-
-The CPAN Forum is a web forum for discussing Perl modules.
-
-L<http://cpanforum.com/dist/XML-Grammar-Fiction>
-
-=item *
-
 CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
@@ -146,7 +136,7 @@ L<http://cpants.cpanauthors.org/dist/XML-Grammar-Fiction>
 
 CPAN Testers
 
-The CPAN Testers is a network of smokers who run automated tests on uploaded CPAN distributions.
+The CPAN Testers is a network of smoke testers who run automated tests on uploaded CPAN distributions.
 
 L<http://www.cpantesters.org/distro/X/XML-Grammar-Fiction>
 
