@@ -1,10 +1,8 @@
 package XML::Grammar::Fiction::FromProto::Node::Description;
-
+$XML::Grammar::Fiction::FromProto::Node::Description::VERSION = 'v0.15.0';
 use strict;
 use warnings;
 
-our $VERSION = 'v0.14.12';
-
 use MooX 'late';
 
 extends("XML::Grammar::Fiction::FromProto::Node::Text");
@@ -19,7 +17,7 @@ __END__
 
 =head1 VERSION
 
-version v0.14.12
+version v0.15.0
 
 =head1 AUTHOR
 
@@ -52,7 +50,7 @@ feature.
 
 You can find documentation for this module with the perldoc command.
 
-  perldoc XML::Grammar::Fiction
+  perldoc XML::Grammar::Fiction::FromProto::Node::Description
 
 =head2 Websites
 
@@ -67,7 +65,7 @@ MetaCPAN
 
 A modern, open-source CPAN search engine, useful to view POD in HTML format.
 
-L<http://metacpan.org/release/XML-Grammar-Fiction>
+L<https://metacpan.org/release/XML-Grammar-Fiction>
 
 =item *
 
@@ -103,14 +101,6 @@ L<http://cpanratings.perl.org/d/XML-Grammar-Fiction>
 
 =item *
 
-CPAN Forum
-
-The CPAN Forum is a web forum for discussing Perl modules.
-
-L<http://cpanforum.com/dist/XML-Grammar-Fiction>
-
-=item *
-
 CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
@@ -121,7 +111,7 @@ L<http://cpants.cpanauthors.org/dist/XML-Grammar-Fiction>
 
 CPAN Testers
 
-The CPAN Testers is a network of smokers who run automated tests on uploaded CPAN distributions.
+The CPAN Testers is a network of smoke testers who run automated tests on uploaded CPAN distributions.
 
 L<http://www.cpantesters.org/distro/X/XML-Grammar-Fiction>
 
