@@ -1,13 +1,11 @@
 package XML::Grammar::Fiction::FromProto::Node::Element;
-
+$XML::Grammar::Fiction::FromProto::Node::Element::VERSION = 'v0.15.0';
 use strict;
 use warnings;
 
 
 use MooX 'late';
 
-our $VERSION = 'v0.14.12';
-
 extends("XML::Grammar::Fiction::FromProto::Node::WithContent");
 
 has 'name' => (isa => 'Str', is => 'rw');
@@ -45,7 +43,11 @@ XML::Grammar::Fiction::FromProto::Node::Element - an XML element node.
 
 =head1 VERSION
 
-version v0.14.12
+version v0.15.0
+
+=head1 VERSION
+
+version v0.15.0
 
 =head1 METHODS
 
@@ -84,7 +86,7 @@ feature.
 
 You can find documentation for this module with the perldoc command.
 
-  perldoc XML::Grammar::Fiction
+  perldoc XML::Grammar::Fiction::FromProto::Node::Element
 
 =head2 Websites
 
@@ -99,7 +101,7 @@ MetaCPAN
 
 A modern, open-source CPAN search engine, useful to view POD in HTML format.
 
-L<http://metacpan.org/release/XML-Grammar-Fiction>
+L<https://metacpan.org/release/XML-Grammar-Fiction>
 
 =item *
 
@@ -135,14 +137,6 @@ L<http://cpanratings.perl.org/d/XML-Grammar-Fiction>
 
 =item *
 
-CPAN Forum
-
-The CPAN Forum is a web forum for discussing Perl modules.
-
-L<http://cpanforum.com/dist/XML-Grammar-Fiction>
-
-=item *
-
 CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
@@ -153,7 +147,7 @@ L<http://cpants.cpanauthors.org/dist/XML-Grammar-Fiction>
 
 CPAN Testers
 
-The CPAN Testers is a network of smokers who run automated tests on uploaded CPAN distributions.
+The CPAN Testers is a network of smoke testers who run automated tests on uploaded CPAN distributions.
 
 L<http://www.cpantesters.org/distro/X/XML-Grammar-Fiction>
 
