@@ -1,12 +1,10 @@
 package XML::Grammar::Fiction::FromProto::Node::InnerDesc;
-
+$XML::Grammar::Fiction::FromProto::Node::InnerDesc::VERSION = 'v0.15.0';
 use strict;
 use warnings;
 
 use MooX 'late';
 
-our $VERSION = 'v0.14.12';
-
 extends("XML::Grammar::Fiction::FromProto::Node::Element");
 
 
@@ -25,7 +23,7 @@ __END__
 
 =head1 VERSION
 
-version v0.14.12
+version v0.15.0
 
 =head1 METHODS
 
@@ -64,7 +62,7 @@ feature.
 
 You can find documentation for this module with the perldoc command.
 
-  perldoc XML::Grammar::Fiction
+  perldoc XML::Grammar::Fiction::FromProto::Node::InnerDesc
 
 =head2 Websites
 
@@ -79,7 +77,7 @@ MetaCPAN
 
 A modern, open-source CPAN search engine, useful to view POD in HTML format.
 
-L<http://metacpan.org/release/XML-Grammar-Fiction>
+L<https://metacpan.org/release/XML-Grammar-Fiction>
 
 =item *
 
@@ -115,14 +113,6 @@ L<http://cpanratings.perl.org/d/XML-Grammar-Fiction>
 
 =item *
 
-CPAN Forum
-
-The CPAN Forum is a web forum for discussing Perl modules.
-
-L<http://cpanforum.com/dist/XML-Grammar-Fiction>
-
-=item *
-
 CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
@@ -133,7 +123,7 @@ L<http://cpants.cpanauthors.org/dist/XML-Grammar-Fiction>
 
 CPAN Testers
 
-The CPAN Testers is a network of smokers who run automated tests on uploaded CPAN distributions.
+The CPAN Testers is a network of smoke testers who run automated tests on uploaded CPAN distributions.
 
 L<http://www.cpantesters.org/distro/X/XML-Grammar-Fiction>
 
