@@ -1,13 +1,11 @@
 package XML::Grammar::Fiction::FromProto::Parser;
-
+$XML::Grammar::Fiction::FromProto::Parser::VERSION = 'v0.15.0';
 use strict;
 use warnings;
 
 use MooX 'late';
 
 
-our $VERSION = 'v0.14.12';
-
 1;
 
 __END__
@@ -21,16 +19,16 @@ __END__
 XML::Grammar::Fiction::FromProto::Parser - base class for parsers of the
 Fiction-XML proto-text.
 
+=head1 VERSION
+
+version v0.15.0
+
+=head1 VERSION
+
+version v0.15.0
+
 B<For internal use only>.
 
-=head1 VERSION
-
-version v0.14.12
-
-=head1 VERSION
-
-Version 0.14.12
-
 =head1 AUTHOR
 
 Shlomi Fish <shlomif@cpan.org>
@@ -62,7 +60,7 @@ feature.
 
 You can find documentation for this module with the perldoc command.
 
-  perldoc XML::Grammar::Fiction
+  perldoc XML::Grammar::Fiction::FromProto::Parser
 
 =head2 Websites
 
@@ -77,7 +75,7 @@ MetaCPAN
 
 A modern, open-source CPAN search engine, useful to view POD in HTML format.
 
-L<http://metacpan.org/release/XML-Grammar-Fiction>
+L<https://metacpan.org/release/XML-Grammar-Fiction>
 
 =item *
 
@@ -113,14 +111,6 @@ L<http://cpanratings.perl.org/d/XML-Grammar-Fiction>
 
 =item *
 
-CPAN Forum
-
-The CPAN Forum is a web forum for discussing Perl modules.
-
-L<http://cpanforum.com/dist/XML-Grammar-Fiction>
-
-=item *
-
 CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
@@ -131,7 +121,7 @@ L<http://cpants.cpanauthors.org/dist/XML-Grammar-Fiction>
 
 CPAN Testers
 
-The CPAN Testers is a network of smokers who run automated tests on uploaded CPAN distributions.
+The CPAN Testers is a network of smoke testers who run automated tests on uploaded CPAN distributions.
 
 L<http://www.cpantesters.org/distro/X/XML-Grammar-Fiction>
 
