@@ -1,5 +1,5 @@
 package XML::Grammar::Fiction::Struct::Tag;
-
+$XML::Grammar::Fiction::Struct::Tag::VERSION = 'v0.15.0';
 use strict;
 use warnings;
 
@@ -8,8 +8,6 @@ use MooX 'late';
 use List::MoreUtils;
 
 
-our $VERSION = 'v0.14.12';
-
 has 'name' => (is => "rw", isa => "Str");
 has 'line' => (is => "rw", isa => "Int");
 has 'is_standalone' => (is => "rw", isa => "Bool");
@@ -53,7 +51,7 @@ sub detach_children
 }
 
 package XML::Grammar::Fiction::Struct::Tag::Para;
-
+$XML::Grammar::Fiction::Struct::Tag::Para::VERSION = 'v0.15.0';
 use MooX 'late';
 
 extends("XML::Grammar::Fiction::Struct::Tag");
@@ -72,16 +70,16 @@ __END__
 XML::Grammar::Fiction::Struct::Tag - information about an XML/SGML opening or
 closing tag.
 
+=head1 VERSION
+
+version v0.15.0
+
+=head1 VERSION
+
+version v0.15.0
+
 B<For internal use only>.
 
-=head1 VERSION
-
-version v0.14.12
-
-=head1 VERSION
-
-Version 0.14.12
-
 =head1 METHODS
 
 =head2 $self->name()
@@ -147,7 +145,7 @@ feature.
 
 You can find documentation for this module with the perldoc command.
 
-  perldoc XML::Grammar::Fiction
+  perldoc XML::Grammar::Fiction::Struct::Tag
 
 =head2 Websites
 
@@ -162,7 +160,7 @@ MetaCPAN
 
 A modern, open-source CPAN search engine, useful to view POD in HTML format.
 
-L<http://metacpan.org/release/XML-Grammar-Fiction>
+L<https://metacpan.org/release/XML-Grammar-Fiction>
 
 =item *
 
@@ -198,14 +196,6 @@ L<http://cpanratings.perl.org/d/XML-Grammar-Fiction>
 
 =item *
 
-CPAN Forum
-
-The CPAN Forum is a web forum for discussing Perl modules.
-
-L<http://cpanforum.com/dist/XML-Grammar-Fiction>
-
-=item *
-
 CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
@@ -216,7 +206,7 @@ L<http://cpants.cpanauthors.org/dist/XML-Grammar-Fiction>
 
 CPAN Testers
 
-The CPAN Testers is a network of smokers who run automated tests on uploaded CPAN distributions.
+The CPAN Testers is a network of smoke testers who run automated tests on uploaded CPAN distributions.
 
 L<http://www.cpantesters.org/distro/X/XML-Grammar-Fiction>
 
