@@ -1,5 +1,5 @@
 package XML::Grammar::FictionBase::Event;
-
+$XML::Grammar::FictionBase::Event::VERSION = 'v0.15.0';
 use strict;
 use warnings;
 
@@ -13,8 +13,6 @@ has 'tag' => (isa => "Maybe[Str]", is => "ro", predicate => '_has_tag',);
 has 'elem' => (is => "ro");
 has 'tag_elem' => (is => "ro");
 
-our $VERSION = 'v0.14.12';
-
 sub is_tag_of_name
 {
     my ($self, $name) = @_;
@@ -48,16 +46,16 @@ __END__
 
 XML::Grammar::FictionBase::Event - a parser event.
 
+=head1 VERSION
+
+version v0.15.0
+
+=head1 VERSION
+
+version v0.15.0
+
 B<For internal use only>.
 
-=head1 VERSION
-
-version v0.14.12
-
-=head1 VERSION
-
-0.11.0
-
 =head1 SLOTS
 
 =head2 $event->elem()
@@ -126,7 +124,7 @@ feature.
 
 You can find documentation for this module with the perldoc command.
 
-  perldoc XML::Grammar::Fiction
+  perldoc XML::Grammar::FictionBase::Event
 
 =head2 Websites
 
@@ -141,7 +139,7 @@ MetaCPAN
 
 A modern, open-source CPAN search engine, useful to view POD in HTML format.
 
-L<http://metacpan.org/release/XML-Grammar-Fiction>
+L<https://metacpan.org/release/XML-Grammar-Fiction>
 
 =item *
 
@@ -177,14 +175,6 @@ L<http://cpanratings.perl.org/d/XML-Grammar-Fiction>
 
 =item *
 
-CPAN Forum
-
-The CPAN Forum is a web forum for discussing Perl modules.
-
-L<http://cpanforum.com/dist/XML-Grammar-Fiction>
-
-=item *
-
 CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
@@ -195,7 +185,7 @@ L<http://cpants.cpanauthors.org/dist/XML-Grammar-Fiction>
 
 CPAN Testers
 
-The CPAN Testers is a network of smokers who run automated tests on uploaded CPAN distributions.
+The CPAN Testers is a network of smoke testers who run automated tests on uploaded CPAN distributions.
 
 L<http://www.cpantesters.org/distro/X/XML-Grammar-Fiction>
 
