@@ -1,5 +1,5 @@
 package XML::Grammar::FictionBase::FromProto::Parser::LineIterator;
-
+$XML::Grammar::FictionBase::FromProto::Parser::LineIterator::VERSION = 'v0.15.0';
 use strict;
 use warnings;
 
@@ -13,9 +13,6 @@ has "_curr_line_idx" => (isa => "Int", is => "rw", reader => "line_idx",);
 has "_lines" => (isa => "ArrayRef", is => "rw");
 
 
-our $VERSION = 'v0.14.12';
-
-
 sub setup_text
 {
     my ($self, $text) = @_;
@@ -249,11 +246,9 @@ __END__
 XML::Grammar::FictionBase::FromProto::Parser::LineIterator - line iterator base
 class for the parser.
 
-B<For internal use only>.
-
 =head1 VERSION
 
-version v0.14.12
+version v0.15.0
 
 =head1 SYNOPSIS
 
@@ -266,7 +261,9 @@ and process it incrementally.
 
 =head1 VERSION
 
-Version 0.14.12
+version v0.15.0
+
+B<For internal use only>.
 
 =head1 METHODS
 
@@ -412,7 +409,7 @@ feature.
 
 You can find documentation for this module with the perldoc command.
 
-  perldoc XML::Grammar::Fiction
+  perldoc XML::Grammar::FictionBase::FromProto::Parser::LineIterator
 
 =head2 Websites
 
@@ -427,7 +424,7 @@ MetaCPAN
 
 A modern, open-source CPAN search engine, useful to view POD in HTML format.
 
-L<http://metacpan.org/release/XML-Grammar-Fiction>
+L<https://metacpan.org/release/XML-Grammar-Fiction>
 
 =item *
 
@@ -463,14 +460,6 @@ L<http://cpanratings.perl.org/d/XML-Grammar-Fiction>
 
 =item *
 
-CPAN Forum
-
-The CPAN Forum is a web forum for discussing Perl modules.
-
-L<http://cpanforum.com/dist/XML-Grammar-Fiction>
-
-=item *
-
 CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
@@ -481,7 +470,7 @@ L<http://cpants.cpanauthors.org/dist/XML-Grammar-Fiction>
 
 CPAN Testers
 
-The CPAN Testers is a network of smokers who run automated tests on uploaded CPAN distributions.
+The CPAN Testers is a network of smoke testers who run automated tests on uploaded CPAN distributions.
 
 L<http://www.cpantesters.org/distro/X/XML-Grammar-Fiction>
 
