@@ -1,5 +1,5 @@
 package XML::Grammar::FictionBase::FromProto::Parser::XmlIterator;
-
+$XML::Grammar::FictionBase::FromProto::Parser::XmlIterator::VERSION = 'v0.15.0';
 use strict;
 use warnings;
 
@@ -907,9 +907,6 @@ sub _main_loop_iter_body
 }
 
 
-our $VERSION = 'v0.14.12';
-
-
 sub process_text
 {
     my ($self, $text) = @_;
@@ -933,11 +930,9 @@ __END__
 XML::Grammar::FictionBase::FromProto::Parser::XmlIterator - line iterator base
 class with some nested XMLisms.
 
-B<For internal use only>.
-
 =head1 VERSION
 
-version v0.14.12
+version v0.15.0
 
 =head1 SYNOPSIS
 
@@ -979,7 +974,9 @@ XML-like grammars.
 
 =head1 VERSION
 
-Version 0.14.12
+version v0.15.0
+
+B<For internal use only>.
 
 =head1 METHODS
 
@@ -1022,7 +1019,7 @@ feature.
 
 You can find documentation for this module with the perldoc command.
 
-  perldoc XML::Grammar::Fiction
+  perldoc XML::Grammar::FictionBase::FromProto::Parser::XmlIterator
 
 =head2 Websites
 
@@ -1037,7 +1034,7 @@ MetaCPAN
 
 A modern, open-source CPAN search engine, useful to view POD in HTML format.
 
-L<http://metacpan.org/release/XML-Grammar-Fiction>
+L<https://metacpan.org/release/XML-Grammar-Fiction>
 
 =item *
 
@@ -1073,14 +1070,6 @@ L<http://cpanratings.perl.org/d/XML-Grammar-Fiction>
 
 =item *
 
-CPAN Forum
-
-The CPAN Forum is a web forum for discussing Perl modules.
-
-L<http://cpanforum.com/dist/XML-Grammar-Fiction>
-
-=item *
-
 CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
@@ -1091,7 +1080,7 @@ L<http://cpants.cpanauthors.org/dist/XML-Grammar-Fiction>
 
 CPAN Testers
 
-The CPAN Testers is a network of smokers who run automated tests on uploaded CPAN distributions.
+The CPAN Testers is a network of smoke testers who run automated tests on uploaded CPAN distributions.
 
 L<http://www.cpantesters.org/distro/X/XML-Grammar-Fiction>
 
