@@ -1,11 +1,9 @@
 package XML::Grammar::Screenplay;
-
+$XML::Grammar::Screenplay::VERSION = 'v0.15.0';
 use warnings;
 use strict;
 
 
-our $VERSION = 'v0.14.12';
-
 
 1;
 
@@ -22,7 +20,7 @@ screenplays.
 
 =head1 VERSION
 
-version v0.14.12
+version v0.15.0
 
 =head1 SYNOPSIS
 
@@ -52,7 +50,7 @@ The rest of this page will document the syntax of the custom textual format.
 
 =head1 VERSION
 
-Version 0.14.12
+version v0.15.0
 
 =head1 FORMAT
 
@@ -222,7 +220,7 @@ feature.
 
 You can find documentation for this module with the perldoc command.
 
-  perldoc XML::Grammar::Fiction
+  perldoc XML::Grammar::Screenplay
 
 =head2 Websites
 
@@ -237,7 +235,7 @@ MetaCPAN
 
 A modern, open-source CPAN search engine, useful to view POD in HTML format.
 
-L<http://metacpan.org/release/XML-Grammar-Fiction>
+L<https://metacpan.org/release/XML-Grammar-Fiction>
 
 =item *
 
@@ -273,14 +271,6 @@ L<http://cpanratings.perl.org/d/XML-Grammar-Fiction>
 
 =item *
 
-CPAN Forum
-
-The CPAN Forum is a web forum for discussing Perl modules.
-
-L<http://cpanforum.com/dist/XML-Grammar-Fiction>
-
-=item *
-
 CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
@@ -291,7 +281,7 @@ L<http://cpants.cpanauthors.org/dist/XML-Grammar-Fiction>
 
 CPAN Testers
 
-The CPAN Testers is a network of smokers who run automated tests on uploaded CPAN distributions.
+The CPAN Testers is a network of smoke testers who run automated tests on uploaded CPAN distributions.
 
 L<http://www.cpantesters.org/distro/X/XML-Grammar-Fiction>
 
