@@ -1,5 +1,5 @@
 package XML::Grammar::Screenplay::App::FromProto;
-
+$XML::Grammar::Screenplay::App::FromProto::VERSION = 'v0.15.0';
 use strict;
 use warnings;
 use autodie;
@@ -13,8 +13,6 @@ use Getopt::Long;
 use XML::Grammar::Screenplay::FromProto;
 use XML::Grammar::Screenplay::FromProto::Parser::QnD;
 
-our $VERSION = 'v0.14.12';
-
 
 sub run
 {
@@ -63,7 +61,7 @@ Screenplay XML.
 
 =head1 VERSION
 
-version v0.14.12
+version v0.15.0
 
 =head1 SYNOPSIS
 
@@ -72,7 +70,7 @@ version v0.14.12
 
 =head1 VERSION
 
-0.11.0
+version v0.15.0
 
 =head1 FUNCTIONS
 
@@ -111,7 +109,7 @@ feature.
 
 You can find documentation for this module with the perldoc command.
 
-  perldoc XML::Grammar::Fiction
+  perldoc XML::Grammar::Screenplay::App::FromProto
 
 =head2 Websites
 
@@ -126,7 +124,7 @@ MetaCPAN
 
 A modern, open-source CPAN search engine, useful to view POD in HTML format.
 
-L<http://metacpan.org/release/XML-Grammar-Fiction>
+L<https://metacpan.org/release/XML-Grammar-Fiction>
 
 =item *
 
@@ -162,14 +160,6 @@ L<http://cpanratings.perl.org/d/XML-Grammar-Fiction>
 
 =item *
 
-CPAN Forum
-
-The CPAN Forum is a web forum for discussing Perl modules.
-
-L<http://cpanforum.com/dist/XML-Grammar-Fiction>
-
-=item *
-
 CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
@@ -180,7 +170,7 @@ L<http://cpants.cpanauthors.org/dist/XML-Grammar-Fiction>
 
 CPAN Testers
 
-The CPAN Testers is a network of smokers who run automated tests on uploaded CPAN distributions.
+The CPAN Testers is a network of smoke testers who run automated tests on uploaded CPAN distributions.
 
 L<http://www.cpantesters.org/distro/X/XML-Grammar-Fiction>
 
