@@ -1,12 +1,10 @@
 package XML::Grammar::Screenplay::FromProto::Parser;
-
+$XML::Grammar::Screenplay::FromProto::Parser::VERSION = 'v0.15.0';
 use strict;
 use warnings;
 
 use MooX 'late';
 
-our $VERSION = 'v0.14.12';
-
 1;
 
 __END__
@@ -20,16 +18,16 @@ __END__
 XML::Grammar::Screenplay::FromProto::Parser - base class for parsers of the
 ScreenplayXML proto-text.
 
+=head1 VERSION
+
+version v0.15.0
+
+=head1 VERSION
+
+version v0.15.0
+
 B<For internal use only>.
 
-=head1 VERSION
-
-version v0.14.12
-
-=head1 VERSION
-
-0.11.0
-
 =head1 AUTHOR
 
 Shlomi Fish <shlomif@cpan.org>
@@ -61,7 +59,7 @@ feature.
 
 You can find documentation for this module with the perldoc command.
 
-  perldoc XML::Grammar::Fiction
+  perldoc XML::Grammar::Screenplay::FromProto::Parser
 
 =head2 Websites
 
@@ -76,7 +74,7 @@ MetaCPAN
 
 A modern, open-source CPAN search engine, useful to view POD in HTML format.
 
-L<http://metacpan.org/release/XML-Grammar-Fiction>
+L<https://metacpan.org/release/XML-Grammar-Fiction>
 
 =item *
 
@@ -112,14 +110,6 @@ L<http://cpanratings.perl.org/d/XML-Grammar-Fiction>
 
 =item *
 
-CPAN Forum
-
-The CPAN Forum is a web forum for discussing Perl modules.
-
-L<http://cpanforum.com/dist/XML-Grammar-Fiction>
-
-=item *
-
 CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
@@ -130,7 +120,7 @@ L<http://cpants.cpanauthors.org/dist/XML-Grammar-Fiction>
 
 CPAN Testers
 
-The CPAN Testers is a network of smokers who run automated tests on uploaded CPAN distributions.
+The CPAN Testers is a network of smoke testers who run automated tests on uploaded CPAN distributions.
 
 L<http://www.cpantesters.org/distro/X/XML-Grammar-Fiction>
 
