@@ -1,5 +1,5 @@
 package XML::Grammar::Screenplay::ToDocBook;
-
+$XML::Grammar::Screenplay::ToDocBook::VERSION = 'v0.15.0';
 use strict;
 use warnings;
 
@@ -20,9 +20,6 @@ has '+to_docbook_xslt_transform_basename' =>
 );
 
 
-our $VERSION = 'v0.14.12';
-
-
 
 sub translate_to_docbook
 {
@@ -48,7 +45,11 @@ XML to DocBook.
 
 =head1 VERSION
 
-version v0.14.12
+version v0.15.0
+
+=head1 VERSION
+
+version v0.15.0
 
 =head1 METHODS
 
@@ -56,10 +57,6 @@ version v0.14.12
 
 Inherited - (to settle pod-coverage).
 
-=head1 VERSION
-
-Version 0.14.12
-
 =head2 new()
 
 Accepts no arguments so far. May take some time as the grammar is compiled
@@ -109,7 +106,7 @@ feature.
 
 You can find documentation for this module with the perldoc command.
 
-  perldoc XML::Grammar::Fiction
+  perldoc XML::Grammar::Screenplay::ToDocBook
 
 =head2 Websites
 
@@ -124,7 +121,7 @@ MetaCPAN
 
 A modern, open-source CPAN search engine, useful to view POD in HTML format.
 
-L<http://metacpan.org/release/XML-Grammar-Fiction>
+L<https://metacpan.org/release/XML-Grammar-Fiction>
 
 =item *
 
@@ -160,14 +157,6 @@ L<http://cpanratings.perl.org/d/XML-Grammar-Fiction>
 
 =item *
 
-CPAN Forum
-
-The CPAN Forum is a web forum for discussing Perl modules.
-
-L<http://cpanforum.com/dist/XML-Grammar-Fiction>
-
-=item *
-
 CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
@@ -178,7 +167,7 @@ L<http://cpants.cpanauthors.org/dist/XML-Grammar-Fiction>
 
 CPAN Testers
 
-The CPAN Testers is a network of smokers who run automated tests on uploaded CPAN distributions.
+The CPAN Testers is a network of smoke testers who run automated tests on uploaded CPAN distributions.
 
 L<http://www.cpantesters.org/distro/X/XML-Grammar-Fiction>
 
