@@ -6,12 +6,10 @@ use warnings;
 use IO::All;
 
 my ($version) =
-    (map { m{\$VERSION *= *'([^']+)'} ? ($1) : () }
-    io->file('lib/XML/Grammar/Fiction.pm')->getlines()
-    )
-    ;
+    ( map { m{\Aversion * = *v?(\S+)} ? ($1) : () }
+        io->file("./dist.ini")->getlines() );
 
-if (!defined ($version))
+if ( !defined($version) )
 {
     die "Version is undefined!";
 }
@@ -22,6 +20,5 @@ my @cmd = (
     "releases/XML-Grammar-Fiction/$version",
 );
 
-print join(" ", map { /\s/ ? qq{"$_"} : $_ } @cmd), "\n";
+print join( " ", map { /\s/ ? qq{"$_"} : $_ } @cmd ), "\n";
 exec(@cmd);
-
